﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XDGHorizontalUnboundSizeDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        TempVM ViewModel = new TempVM();
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = ViewModel;
        }
        
        void xamDataGrid_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            List<ISimulatedValue> container = this.ViewModel.Columns;

            e.FieldLayout.Fields.Add(new Field
            {
                Name = "Name",
                Label = "Index",
                AllowEdit = false,
                Height = new FieldLength(40),
                Width = new FieldLength(20)
            });

            int size = 0;

            //  Find the longest array.
            foreach (ISimulatedValue sim in container)
            {
                size = Math.Max(size, sim.AllValues.Length);
            }
            //  Create a field for each value in the longest array.
            for (int i = 0; i < size; i++)
            {
                
                var field = new NumericField
                {
                    Label = i,
                    AlternateBinding = new Binding(String.Format("{0}[{1}]", nameof(ISimulatedValue.AllValues), i)),
                    AllowEdit = false,
                    Height = new FieldLength(40)
                    //Format = "P2"
                };

                if(i% 2 == 0)
                {
                    Style cvpStyle = layoutRoot.Resources["altCVPStyle"] as Style;
                    field.CellValuePresenterStyle = cvpStyle;
                }

                field.Settings.EditAsType = typeof(String);
                e.FieldLayout.Fields.Add(field);
            }
        }
    }

    public class TempVM
    {
        public TempVM()
        {
            Columns = new List<ISimulatedValue>();
            Columns.Add(new Values("New Name", 100));
            Columns.Add(new Values("New Name2", -100));
        }

        public List<ISimulatedValue> Columns { get; set; }
    }

    public class Values : ISimulatedValue
    {
        public Values(string name, int ratio)
        {
            Name = name;

            //  Generate the sample array data.
            List<double> list = new List<double>();

            for (int i = 0; i < 100; ++i)
            {
                list.Add(ratio * i);
            }
            AllValues = list.ToArray<double>();
        }

        public string Name { get; set; }
        public double[] AllValues { get; set; }
    }

    public interface ISimulatedValue
    {
        string Name { get; set; }
        double[] AllValues { get; set; }
    }
}
